@@ -127,7 +127,7 @@ gs_utils_filename_array_return_newest (GPtrArray *array)
 
 /**
  * gs_utils_get_cache_filename:
- * @kind: A cache kind, e.g. "firmware" or "screenshots/123x456"
+ * @kind: A cache kind, e.g. "fwupd" or "screenshots/123x456"
  * @resource: A resource, e.g. "system.bin" or "http://foo.bar/baz.bin"
  * @flags: Some #GsUtilsCacheFlags, e.g. %GS_UTILS_CACHE_FLAG_WRITEABLE
  * @error: A #GError, or %NULL
@@ -142,6 +142,11 @@ gs_utils_filename_array_return_newest (GPtrArray *array)
  * If there is more than one match, the file that has been modified last is
  * returned.
  *
+ * If a plugin requests a file to be saved in the cache it is the plugins
+ * responsibility to remove the file when it is no longer valid or is too old
+ * -- gnome-software will not ever clean the cache for the plugin.
+ * For this reason it is a good idea to use the plugin name as @kind.
+ *
  * Returns: The full path and filename, which may or may not exist, or %NULL
  **/
 gchar *
@@ -152,8 +157,6 @@ gs_utils_get_cache_filename (const gchar *kind,
 {
 	g_autofree gchar *basename = NULL;
 	g_autofree gchar *cachedir = NULL;
-	g_autofree gchar *vername = NULL;
-	g_auto(GStrv) version = g_strsplit (VERSION, ".", 3);
 	g_autoptr(GFile) cachedir_file = NULL;
 	g_autoptr(GPtrArray) candidates = g_ptr_array_new_with_free_func (g_free);
 
@@ -199,10 +202,8 @@ gs_utils_get_cache_filename (const gchar *kind,
 
 	/* create the cachedir in a per-release location, creating
 	 * if it does not already exist */
-	vername = g_strdup_printf ("%s.%s", version[0], version[1]);
 	cachedir = g_build_filename (g_get_user_cache_dir (),
 				     "gnome-software",
-				     vername,
 				     kind,
 				     NULL);
 	cachedir_file = g_file_new_for_path (cachedir);
@@ -257,26 +258,30 @@ gs_utils_get_user_hash (GError **error)
 /**
  * gs_utils_get_permission:
  * @id: A PolicyKit ID, e.g. "org.gnome.Desktop"
+ * @cancellable: A #GCancellable, or %NULL
+ * @error: A #GError, or %NULL
  *
  * Gets a permission object for an ID.
  *
  * Returns: a #GPermission, or %NULL if this if not possible.
  **/
 GPermission *
-gs_utils_get_permission (const gchar *id)
+gs_utils_get_permission (const gchar *id, GCancellable *cancellable, GError **error)
 {
 #ifdef HAVE_POLKIT
 	g_autoptr(GPermission) permission = NULL;
-	g_autoptr(GError) error = NULL;
-
-	permission = polkit_permission_new_sync (id, NULL, NULL, &error);
+	permission = polkit_permission_new_sync (id, NULL, cancellable, error);
 	if (permission == NULL) {
-		g_warning ("Failed to create permission %s: %s", id, error->message);
+		g_prefix_error (error, "failed to create permission %s: ", id);
+		gs_utils_error_convert_gio (error);
 		return NULL;
 	}
 	return g_steal_pointer (&permission);
 #else
-	g_debug ("no PolicyKit, so can't return GPermission for %s", id);
+	g_set_error (error,
+		     GS_PLUGIN_ERROR,
+		     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+		     "no PolicyKit, so can't return GPermission for %s", id);
 	return NULL;
 #endif
 }
