@@ -102,11 +102,6 @@ void
 gs_plugin_initialize (GsPlugin *plugin)
 {
 	GsPluginData *priv = gs_plugin_alloc_data (plugin, sizeof(GsPluginData));
-#if FWUPD_CHECK_VERSION(1,0,3)
-	g_autofree gchar *user_agent = NULL;
-#endif
-	g_autoptr(SoupSession) soup_session = NULL;
-
 	priv->client = fwupd_client_new ();
 	priv->to_download = g_ptr_array_new_with_free_func (g_free);
 	priv->to_ignore = g_ptr_array_new_with_free_func (g_free);
@@ -125,22 +120,6 @@ gs_plugin_initialize (GsPlugin *plugin)
 	}
 #endif
 
-#if FWUPD_CHECK_VERSION(1,0,3)
-	/* use a custom user agent to provide the fwupd version */
-	user_agent = fwupd_build_user_agent (PACKAGE_NAME, PACKAGE_VERSION);
-	soup_session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT, user_agent,
-						      SOUP_SESSION_TIMEOUT, 10,
-						      NULL);
-#else
-	/* use a custom session with the content decoder turned off */
-	soup_session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT, gs_user_agent (),
-						      SOUP_SESSION_TIMEOUT, 10,
-						      NULL);
-#endif
-	soup_session_remove_feature_by_type (soup_session,
-					     SOUP_TYPE_CONTENT_DECODER);
-	gs_plugin_set_soup_session (plugin, soup_session);
-
 	/* set name of MetaInfo file */
 	gs_plugin_set_appstream_id (plugin, "org.gnome.Software.Plugin.Fwupd");
 }
@@ -279,7 +258,7 @@ gs_plugin_fwupd_setup_remote (GsPlugin *plugin, FwupdRemote *remote, GError **er
 		return TRUE;
 
 	/* find the name of the signature file in the cache */
-	filename_asc = gs_utils_get_cache_filename ("firmware",
+	filename_asc = gs_utils_get_cache_filename ("fwupd",
 						    fwupd_remote_get_filename_asc (remote),
 						    GS_UTILS_CACHE_FLAG_WRITEABLE,
 						    error);
@@ -437,55 +416,6 @@ gs_plugin_fwupd_new_app_from_results (GsPlugin *plugin, FwupdResult *res)
 	return app;
 }
 
-#if FWUPD_CHECK_VERSION(1,0,0)
-static gchar *
-gs_plugin_fwupd_build_device_id (FwupdDevice *dev)
-{
-	g_autofree gchar *tmp = g_strdup (fwupd_device_get_id (dev));
-	g_strdelimit (tmp, "/", '_');
-	return g_strdup_printf ("org.fwupd.%s.device", tmp);
-}
-
-static GsApp *
-gs_plugin_fwupd_new_app_from_device_raw (GsPlugin *plugin, FwupdDevice *device)
-{
-	GPtrArray *icons;
-	g_autofree gchar *id = NULL;
-	g_autoptr(GsApp) app = NULL;
-
-	/* create a GsApp based on the device, not the release */
-	id = gs_plugin_fwupd_build_device_id (device);
-	app = gs_app_new (id);
-	gs_app_set_kind (app, AS_APP_KIND_FIRMWARE);
-	gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
-	gs_app_set_state (app, AS_APP_STATE_INSTALLED);
-	gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
-	gs_app_set_version (app, fwupd_device_get_version (device));
-	gs_app_set_name (app, GS_APP_QUALITY_LOWEST, fwupd_device_get_name (device));
-	gs_app_set_summary (app, GS_APP_QUALITY_LOWEST, fwupd_device_get_summary (device));
-	gs_app_set_description (app, GS_APP_QUALITY_LOWEST, fwupd_device_get_description (device));
-	gs_app_set_origin (app, fwupd_device_get_vendor (device));
-	gs_fwupd_app_set_device_id (app, fwupd_device_get_id (device));
-	gs_app_set_management_plugin (app, "fwupd");
-
-	/* create icon */
-	icons = fwupd_device_get_icons (device);
-	for (guint j = 0; j < icons->len; j++) {
-		const gchar *icon = g_ptr_array_index (icons, j);
-		g_autoptr(AsIcon) icon_tmp = as_icon_new ();
-		if (g_str_has_prefix (icon, "/")) {
-			as_icon_set_kind (icon_tmp, AS_ICON_KIND_LOCAL);
-			as_icon_set_filename (icon_tmp, icon);
-		} else {
-			as_icon_set_kind (icon_tmp, AS_ICON_KIND_STOCK);
-			as_icon_set_name (icon_tmp, icon);
-		}
-		gs_app_add_icon (app, icon_tmp);
-	}
-	return g_steal_pointer (&app);
-}
-#endif
-
 static gboolean
 gs_plugin_add_update_app (GsPlugin *plugin,
 			  GsAppList *list,
@@ -560,7 +490,7 @@ gs_plugin_add_update_app (GsPlugin *plugin,
 
 	/* does the firmware already exist in the cache? */
 	basename = g_path_get_basename (update_uri);
-	filename_cache = gs_utils_get_cache_filename ("firmware",
+	filename_cache = gs_utils_get_cache_filename ("fwupd",
 						      basename,
 						      GS_UTILS_CACHE_FLAG_NONE,
 						      error);
@@ -711,7 +641,7 @@ gs_plugin_fwupd_add_updates (GsPlugin *plugin,
 		/* locked device that needs unlocking */
 		if (fwupd_device_has_flag (dev, FWUPD_DEVICE_FLAG_LOCKED)) {
 			g_autoptr(GsApp) app = NULL;
-			app = gs_plugin_fwupd_new_app_from_device_raw (plugin, dev);
+			app = gs_plugin_fwupd_new_app_from_device (plugin, dev);
 			gs_fwupd_app_set_is_locked (app, TRUE);
 			gs_app_list_add (list, app);
 			continue;
@@ -942,7 +872,7 @@ gs_plugin_fwupd_refresh_remote (GsPlugin *plugin,
 	}
 
 	/* check cache age */
-	filename_asc = gs_utils_get_cache_filename ("firmware",
+	filename_asc = gs_utils_get_cache_filename ("fwupd",
 						    fwupd_remote_get_filename_asc (remote),
 						    GS_UTILS_CACHE_FLAG_WRITEABLE,
 						    error);
@@ -997,7 +927,7 @@ gs_plugin_fwupd_refresh_remote (GsPlugin *plugin,
 			     g_steal_pointer (&checksum));
 
 	/* download the payload and save to file */
-	filename = gs_utils_get_cache_filename ("firmware",
+	filename = gs_utils_get_cache_filename ("fwupd",
 						fwupd_remote_get_filename (remote),
 						GS_UTILS_CACHE_FLAG_WRITEABLE,
 						error);
@@ -1087,7 +1017,7 @@ gs_plugin_refresh (GsPlugin *plugin,
 
 		tmp = g_ptr_array_index (priv->to_download, i);
 		basename = g_path_get_basename (tmp);
-		filename_cache = gs_utils_get_cache_filename ("firmware",
+		filename_cache = gs_utils_get_cache_filename ("fwupd",
 							      basename,
 							      GS_UTILS_CACHE_FLAG_WRITEABLE,
 							      error);
@@ -1171,6 +1101,28 @@ gs_plugin_fwupd_install (GsPlugin *plugin,
 	return TRUE;
 }
 
+static gboolean
+gs_plugin_fwupd_modify_source (GsPlugin *plugin, GsApp *app, gboolean enabled,
+			       GCancellable *cancellable, GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	const gchar *remote_id = gs_app_get_metadata_item (app, "fwupd::remote-id");
+	if (remote_id == NULL) {
+		g_set_error (error,
+			     GS_PLUGIN_ERROR,
+			     GS_PLUGIN_ERROR_FAILED,
+			     "not enough data for fwupd %s",
+			     gs_app_get_unique_id (app));
+		return FALSE;
+	}
+	return fwupd_client_modify_remote (priv->client,
+					   remote_id,
+					   "Enabled",
+					   enabled ? "true" : "false",
+					   cancellable,
+					   error);
+}
+
 gboolean
 gs_plugin_app_install (GsPlugin *plugin,
 		       GsApp *app,
@@ -1182,9 +1134,29 @@ gs_plugin_app_install (GsPlugin *plugin,
 		       gs_plugin_get_name (plugin)) != 0)
 		return TRUE;
 
+	/* source -> remote */
+	if (gs_app_get_kind (app) == AS_APP_KIND_SOURCE) {
+		return gs_plugin_fwupd_modify_source (plugin, app, TRUE,
+						      cancellable, error);
+	}
+
+	/* firmware */
 	return gs_plugin_fwupd_install (plugin, app, cancellable, error);
 }
 
+gboolean
+gs_plugin_app_remove (GsPlugin *plugin, GsApp *app,
+		      GCancellable *cancellable, GError **error)
+{
+	/* only process this app if was created by this plugin */
+	if (g_strcmp0 (gs_app_get_management_plugin (app),
+		       gs_plugin_get_name (plugin)) != 0)
+		return TRUE;
+
+	/* source -> remote */
+	return gs_plugin_fwupd_modify_source (plugin, app, TRUE, cancellable, error);
+}
+
 gboolean
 gs_plugin_update_app (GsPlugin *plugin,
 		      GsApp *app,
@@ -1300,3 +1272,157 @@ gs_plugin_file_to_app (GsPlugin *plugin,
 
 	return TRUE;
 }
+
+gboolean
+gs_plugin_add_sources (GsPlugin *plugin,
+		       GsAppList *list,
+		       GCancellable *cancellable,
+		       GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_autoptr(GPtrArray) remotes = NULL;
+
+	/* find all remotes */
+	remotes = fwupd_client_get_remotes (priv->client, cancellable, error);
+	if (remotes == NULL)
+		return FALSE;
+	for (guint i = 0; i < remotes->len; i++) {
+		FwupdRemote *remote = g_ptr_array_index (remotes, i);
+		g_autofree gchar *id = NULL;
+		g_autoptr(GsApp) app = NULL;
+
+		/* ignore these, they're built in */
+		if (fwupd_remote_get_kind (remote) == FWUPD_REMOTE_KIND_LOCAL)
+			continue;
+
+		/* create something that we can use to enable/disable */
+		id = g_strdup_printf ("org.fwupd.%s.remote", fwupd_remote_get_id (remote));
+		app = gs_app_new (id);
+		gs_app_set_kind (app, AS_APP_KIND_SOURCE);
+		gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
+		gs_app_set_state (app, fwupd_remote_get_enabled (remote) ?
+				  AS_APP_STATE_INSTALLED : AS_APP_STATE_AVAILABLE);
+		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
+		gs_app_set_name (app, GS_APP_QUALITY_LOWEST,
+				 fwupd_remote_get_id (remote));
+		gs_app_set_summary (app, GS_APP_QUALITY_LOWEST,
+				    fwupd_remote_get_title (remote));
+		gs_app_set_url (app, AS_URL_KIND_HOMEPAGE,
+				fwupd_remote_get_metadata_uri (remote));
+		gs_app_set_metadata (app, "fwupd::remote-id",
+				     fwupd_remote_get_id (remote));
+		gs_app_list_add (list, app);
+	}
+	return TRUE;
+}
+
+#if FWUPD_CHECK_VERSION(1,0,0)
+static gchar *
+gs_plugin_fwupd_build_device_id (FwupdDevice *dev)
+{
+	g_autofree gchar *tmp = g_strdup (fwupd_device_get_id (dev));
+	g_strdelimit (tmp, "/", '_');
+	return g_strdup_printf ("org.fwupd.%s.device", tmp);
+}
+
+static gboolean
+gs_plugin_fwupd_add_releases (GsPlugin *plugin, GsApp *app,
+			      GCancellable *cancellable, GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(GPtrArray) releases = NULL;
+
+	releases = fwupd_client_get_releases (priv->client,
+					      gs_app_get_metadata_item (app, "fwupd::device-id"),
+					      cancellable,
+					      &error_local);
+	if (releases == NULL) {
+		/* just ignore empty array */
+		if (g_error_matches (error_local,
+				     FWUPD_ERROR,
+				     FWUPD_ERROR_NOTHING_TO_DO)) {
+			return TRUE;
+		}
+		g_propagate_error (error, g_steal_pointer (&error_local));
+		return FALSE;
+	}
+	for (guint j = 0; j < releases->len; j++) {
+		FwupdRelease *rel = g_ptr_array_index (releases, j);
+		g_autoptr(GsApp) app2 = gs_app_new (NULL);
+		gs_fwupd_app_set_from_release (app2, rel);
+		gs_app_add_history (app, app2);
+	}
+	return TRUE;
+}
+
+static gboolean
+gs_plugin_fwupd_add_devices (GsPlugin *plugin, GsAppList *list,
+			     GCancellable *cancellable, GError **error)
+{
+	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_autoptr(GPtrArray) devices = NULL;
+
+	/* get devices */
+	devices = fwupd_client_get_devices (priv->client, cancellable, error);
+	if (devices == NULL)
+		return FALSE;
+	for (guint i = 0; i < devices->len; i++) {
+		FwupdDevice *device = g_ptr_array_index (devices, i);
+		GPtrArray *icons;
+		g_autofree gchar *id = NULL;
+		g_autoptr(GsApp) app = NULL;
+
+		/* ignore these, we can't do anything */
+		if (!fwupd_device_has_flag (device, FWUPD_DEVICE_FLAG_UPDATABLE))
+			continue;
+
+		/* create something that we can use to enable/disable */
+		id = gs_plugin_fwupd_build_device_id (device);
+		app = gs_app_new (id);
+		gs_app_set_kind (app, AS_APP_KIND_FIRMWARE);
+		gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
+		gs_app_set_state (app, AS_APP_STATE_INSTALLED);
+		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
+		gs_app_set_version (app, fwupd_device_get_version (device));
+		gs_app_set_name (app, GS_APP_QUALITY_LOWEST, fwupd_device_get_name (device));
+		gs_app_set_summary (app, GS_APP_QUALITY_LOWEST, fwupd_device_get_summary (device));
+		gs_app_set_description (app, GS_APP_QUALITY_LOWEST, fwupd_device_get_description (device));
+		gs_app_set_origin (app, fwupd_device_get_vendor (device));
+		gs_app_set_metadata (app, "fwupd::device-id", fwupd_device_get_id (device));
+		gs_app_set_management_plugin (app, "fwupd");
+		gs_app_list_add (list, app);
+
+		/* create icon */
+		icons = fwupd_device_get_icons (device);
+		for (guint j = 0; j < icons->len; j++) {
+			const gchar *icon = g_ptr_array_index (icons, j);
+			g_autoptr(AsIcon) icon_tmp = as_icon_new ();
+			if (g_str_has_prefix (icon, "/")) {
+				as_icon_set_kind (icon_tmp, AS_ICON_KIND_LOCAL);
+				as_icon_set_filename (icon_tmp, icon);
+			} else {
+				as_icon_set_kind (icon_tmp, AS_ICON_KIND_STOCK);
+				as_icon_set_name (icon_tmp, icon);
+			}
+			gs_app_add_icon (app, icon_tmp);
+		}
+
+		/* add releases */
+		if (!gs_plugin_fwupd_add_releases (plugin, app, cancellable, error))
+			return FALSE;
+	}
+	return TRUE;
+}
+#endif
+
+gboolean
+gs_plugin_add_search (GsPlugin *plugin, gchar **values, GsAppList *list,
+		      GCancellable *cancellable, GError **error)
+{
+#if FWUPD_CHECK_VERSION(1,0,0)
+	if (g_strv_contains ((const gchar * const *) values, "fwupd"))
+		return gs_plugin_fwupd_add_devices (plugin, list, cancellable, error);
+#endif
+	return TRUE;
+}
