@@ -284,10 +284,7 @@ gs_plugin_setup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 	/* not running under Shell */
 	name_owner = g_dbus_proxy_get_name_owner (priv->proxy);
 	if (name_owner == NULL) {
-		g_set_error_literal (error,
-				     GS_PLUGIN_ERROR,
-				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
-				     "gnome-shell is not running");
+		g_clear_object (&priv->proxy);
 		return FALSE;
 	}
 
@@ -598,7 +595,7 @@ gs_plugin_shell_extensions_parse_apps (GsPlugin *plugin,
 	}
 
 	/* load extensions */
-	apps = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	apps = g_ptr_array_new ();
 	json_extensions = json_object_get_member (json_item, "extensions");
 	if (json_extensions == NULL) {
 		g_set_error_literal (error,
@@ -649,7 +646,7 @@ gs_plugin_shell_extensions_get_apps (GsPlugin *plugin,
 	g_autoptr(GsApp) app_dl = gs_app_new (gs_plugin_get_name (plugin));
 
 	/* look in the cache */
-	cachefn = gs_utils_get_cache_filename ("extensions",
+	cachefn = gs_utils_get_cache_filename ("shell-extensions",
 					       "gnome.json",
 					       GS_UTILS_CACHE_FLAG_WRITEABLE,
 					       error);
