@@ -22,11 +22,13 @@
 #include <config.h>
 
 #include <gio/gdesktopappinfo.h>
+#include <glib/gi18n.h>
 #include <snapd-glib/snapd-glib.h>
 #include <gnome-software.h>
 
 struct GsPluginData {
 	SnapdAuthData		*auth_data;
+	gchar			*store_name;
 	gboolean		 snapd_supports_polkit;
 	SnapdSystemConfinement	 system_confinement;
 	GsAuth			*auth;
@@ -206,6 +208,10 @@ gs_plugin_setup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 	system_information = snapd_client_get_system_information_sync (client, cancellable, error);
 	if (system_information == NULL)
 		return FALSE;
+	priv->store_name = g_strdup (snapd_system_information_get_store (system_information));
+	if (priv->store_name == NULL)
+		priv->store_name = g_strdup (/* TRANSLATORS: default snap store name */
+					     _("Snap Store"));
 	priv->system_confinement = snapd_system_information_get_confinement (system_information);
 
 	version = g_strsplit (snapd_system_information_get_version (system_information), ".", -1);
@@ -377,6 +383,7 @@ void
 gs_plugin_destroy (GsPlugin *plugin)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
+	g_free (priv->store_name);
 	g_clear_object (&priv->auth);
 	g_clear_pointer (&priv->store_snaps, g_hash_table_unref);
 	g_mutex_clear (&priv->store_snaps_lock);
@@ -560,15 +567,7 @@ gs_plugin_add_search (GsPlugin *plugin,
 static gboolean
 load_icon (GsPlugin *plugin, SnapdClient *client, GsApp *app, const gchar *icon_url, GCancellable *cancellable, GError **error)
 {
-	if (icon_url == NULL || g_strcmp0 (icon_url, "") == 0) {
-		g_autoptr(AsIcon) icon = as_icon_new ();
-		as_icon_set_kind (icon, AS_ICON_KIND_STOCK);
-		as_icon_set_name (icon, "package-x-generic");
-		gs_app_add_icon (app, icon);
-		return TRUE;
-	}
-
-	/* icon is optional, either loaded from snapd or from a URL */
+	/* icon is either loaded from snapd or from a URL */
 	if (g_str_has_prefix (icon_url, "/")) {
 		g_autoptr(SnapdIcon) icon = NULL;
 
@@ -658,6 +657,15 @@ find_launch_app (GsApp *app, SnapdSnap *local_snap)
 		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
 }
 
+static gchar *
+gs_plugin_snap_get_description_safe (SnapdSnap *snap)
+{
+	GString *str = g_string_new (snapd_snap_get_description (snap));
+	as_utils_string_replace (str, "\r", "");
+	as_utils_string_replace (str, "  ", " ");
+	return g_string_free (str, FALSE);
+}
+
 gboolean
 gs_plugin_refine_app (GsPlugin *plugin,
 		      GsApp *app,
@@ -665,6 +673,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 		      GCancellable *cancellable,
 		      GError **error)
 {
+	GsPluginData *priv = gs_plugin_get_data (plugin);
 	g_autoptr(SnapdClient) client = NULL;
 	const gchar *id, *icon_url = NULL;
 	g_autoptr(SnapdSnap) local_snap = NULL;
@@ -688,6 +697,7 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	local_snap = snapd_client_list_one_sync (client, id, cancellable, NULL);
 	if (local_snap != NULL) {
 		const gchar *name;
+		g_autofree gchar *description = NULL;
 		if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN)
 			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 		name = snapd_snap_get_title (local_snap);
@@ -695,7 +705,10 @@ gs_plugin_refine_app (GsPlugin *plugin,
 			name = snapd_snap_get_name (local_snap);
 		gs_app_set_name (app, GS_APP_QUALITY_NORMAL, name);
 		gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_summary (local_snap));
-		gs_app_set_description (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_description (local_snap));
+		description = gs_plugin_snap_get_description_safe (local_snap);
+		if (description != NULL)
+			gs_app_set_description (app, GS_APP_QUALITY_NORMAL, description);
+		gs_app_set_license (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_license (local_snap));
 		gs_app_set_version (app, snapd_snap_get_version (local_snap));
 		gs_app_set_size_installed (app, snapd_snap_get_installed_size (local_snap));
 		gs_app_set_install_date (app, g_date_time_to_unix (snapd_snap_get_install_date (local_snap)));
@@ -711,7 +724,8 @@ gs_plugin_refine_app (GsPlugin *plugin,
 	store_snap = get_store_snap (plugin, id, cancellable, NULL);
 	if (store_snap != NULL) {
 		GPtrArray *screenshots;
-		const gchar *name, *screenshot_url = NULL;
+		const gchar *name;
+		g_autofree gchar *description = NULL;
 
 		if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN)
 			gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
@@ -721,7 +735,10 @@ gs_plugin_refine_app (GsPlugin *plugin,
 			name = snapd_snap_get_name (store_snap);
 		gs_app_set_name (app, GS_APP_QUALITY_NORMAL, name);
 		gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_summary (store_snap));
-		gs_app_set_description (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_description (store_snap));
+		description = gs_plugin_snap_get_description_safe (store_snap);
+		if (description != NULL)
+			gs_app_set_description (app, GS_APP_QUALITY_NORMAL, description);
+		gs_app_set_license (app, GS_APP_QUALITY_NORMAL, snapd_snap_get_license (store_snap));
 		gs_app_set_version (app, snapd_snap_get_version (store_snap));
 		gs_app_set_size_download (app, snapd_snap_get_download_size (store_snap));
 		gs_app_set_developer_name (app, snapd_snap_get_developer (store_snap));
@@ -757,20 +774,10 @@ gs_plugin_refine_app (GsPlugin *plugin,
 				as_image_set_height (image, snapd_screenshot_get_height (screenshot));
 				as_screenshot_add_image (ss, image);
 				gs_app_add_screenshot (app, ss);
-
-				/* fall back to the screenshot */
-				if (screenshot_url == NULL)
-					screenshot_url = snapd_screenshot_get_url (screenshot);
 			}
 		}
 
-		/* use some heuristics to guess the application origin */
-		if (gs_app_get_origin_hostname (app) == NULL) {
-			if (icon_url != NULL && !g_str_has_prefix (icon_url, "/"))
-				gs_app_set_origin_hostname (app, icon_url);
-			else if (screenshot_url != NULL)
-				gs_app_set_origin_hostname (app, screenshot_url);
-		}
+		gs_app_set_origin (app, priv->store_name);
 	}
 
 	/* load icon if requested */
@@ -950,21 +957,12 @@ gs_plugin_auth_login (GsPlugin *plugin, GsAuth *auth,
 	g_clear_object (&priv->auth_data);
 	if (priv->snapd_supports_polkit) {
 		g_autoptr(SnapdClient) client = NULL;
-#ifdef SNAPD_GLIB_VERSION_1_26
-		g_autoptr(SnapdUserInformation) user_information = NULL;
-#endif
 
 		client = get_client (plugin, error);
 		if (client == NULL)
 			return FALSE;
 
-#ifdef SNAPD_GLIB_VERSION_1_26
-		user_information = snapd_client_login2_sync (client, gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
-		if (user_information != NULL)
-			priv->auth_data = g_object_ref (snapd_user_information_get_auth_data (user_information));
-#else
 		priv->auth_data = snapd_client_login_sync (client, gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
-#endif
 	}
 	else
 		priv->auth_data = snapd_login_sync (gs_auth_get_username (auth), gs_auth_get_password (auth), gs_auth_get_pin (auth), NULL, error);
