@@ -39,7 +39,6 @@ typedef struct
 	GtkWidget	*version_label;
 	GtkWidget	*star;
 	GtkWidget	*folder_label;
-	GtkWidget	*description_box;
 	GtkWidget	*description_label;
 	GtkWidget	*button_box;
 	GtkWidget	*button;
@@ -54,6 +53,7 @@ typedef struct
 	gboolean	 show_folders;
 	gboolean	 show_buttons;
 	gboolean	 show_source;
+	gboolean	 show_codec;
 	gboolean	 show_update;
 	gboolean	 show_installed_size;
 	gboolean	 selectable;
@@ -258,10 +258,10 @@ gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 		case AS_APP_STATE_UPDATABLE:
 		case AS_APP_STATE_INSTALLED:
 		case AS_APP_STATE_UPDATABLE_LIVE:
-			gtk_style_context_add_class (context, "destructive-action");
+			gtk_style_context_remove_class (context, "destructive-action");
 			break;
 		default:
-			gtk_style_context_remove_class (context, "destructive-action");
+			gtk_style_context_add_class (context, "destructive-action");
 			break;
 		}
 	}
@@ -276,7 +276,8 @@ gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 			gtk_widget_set_sensitive (priv->button, FALSE);
 			break;
 		default:
-			gtk_widget_set_sensitive (priv->button, TRUE);
+			gtk_widget_set_sensitive (priv->button,
+						  gs_app_get_allow_cancel (priv->app));
 			break;
 		}
 	}
@@ -664,7 +665,6 @@ gs_app_row_class_init (GsAppRowClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, version_label);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, star);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, folder_label);
-	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, description_box);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, description_label);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, button_box);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, button);
@@ -698,6 +698,7 @@ gs_app_row_init (GsAppRow *app_row)
 	gtk_widget_init_template (GTK_WIDGET (app_row));
 	gs_star_widget_set_icon_size (GS_STAR_WIDGET (priv->star), 12);
 
+	priv->colorful = TRUE;
 	priv->settings = g_settings_new ("org.gnome.software");
 
 	g_signal_connect (priv->button, "clicked",
@@ -713,14 +714,12 @@ void
 gs_app_row_set_size_groups (GsAppRow *app_row,
 			    GtkSizeGroup *image,
 			    GtkSizeGroup *name,
-			    GtkSizeGroup *desc,
 			    GtkSizeGroup *button)
 {
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
 	gtk_size_group_add_widget (image, priv->image);
 	gtk_size_group_add_widget (name, priv->name_box);
-	gtk_size_group_add_widget (desc, priv->description_box);
 	gtk_size_group_add_widget (button, priv->button);
 }
 
@@ -760,6 +759,15 @@ gs_app_row_set_show_source (GsAppRow *app_row, gboolean show_source)
 	gs_app_row_refresh (app_row);
 }
 
+void
+gs_app_row_set_show_codec (GsAppRow *app_row, gboolean show_codec)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	priv->show_codec = show_codec;
+	gs_app_row_refresh (app_row);
+}
+
 void
 gs_app_row_set_show_installed_size (GsAppRow *app_row, gboolean show_size)
 {
