@@ -62,7 +62,6 @@ struct _GsDetailsPage
 	GsShell			*shell;
 	SoupSession		*session;
 	gboolean		 enable_reviews;
-	gboolean		 show_all_reviews;
 	GSettings		*settings;
 
 	GtkWidget		*application_details_icon;
@@ -107,7 +106,6 @@ struct _GsDetailsPage
 	GtkWidget		*label_details_size_installed_value;
 	GtkWidget		*label_details_size_download_title;
 	GtkWidget		*label_details_size_download_value;
-	GtkWidget		*label_details_updated_title;
 	GtkWidget		*label_details_updated_value;
 	GtkWidget		*label_details_version_value;
 	GtkWidget		*label_failed;
@@ -610,8 +608,6 @@ gs_details_page_refresh_screenshots (GsDetailsPage *self)
 			gtk_box_pack_start (GTK_BOX (self->box_details_screenshot_main), ssimg, FALSE, FALSE, 0);
 			gtk_widget_set_visible (ssimg, TRUE);
 		}
-		gtk_widget_set_visible (self->box_details_screenshot_fallback,
-		                        screenshots->len == 0);
 		return;
 	}
 
@@ -786,6 +782,36 @@ gs_details_page_history_cb (GtkLabel *label,
 	return TRUE;
 }
 
+static void
+gs_details_page_refresh_size (GsDetailsPage *self)
+{
+	/* set the installed size */
+	if (gs_app_get_size_installed (self->app) != GS_APP_SIZE_UNKNOWABLE &&
+	    gs_app_get_size_installed (self->app) != 0) {
+		g_autofree gchar *size = NULL;
+		size = g_format_size (gs_app_get_size_installed (self->app));
+		gtk_label_set_label (GTK_LABEL (self->label_details_size_installed_value), size);
+		gtk_widget_show (self->label_details_size_installed_title);
+		gtk_widget_show (self->label_details_size_installed_value);
+	} else {
+		gtk_widget_hide (self->label_details_size_installed_title);
+		gtk_widget_hide (self->label_details_size_installed_value);
+	}
+
+	/* set the download size */
+	if (!gs_app_is_installed (self->app) &&
+	    gs_app_get_size_download (self->app) != GS_APP_SIZE_UNKNOWABLE) {
+		g_autofree gchar *size = NULL;
+		size = g_format_size (gs_app_get_size_download (self->app));
+		gtk_label_set_label (GTK_LABEL (self->label_details_size_download_value), size);
+		gtk_widget_show (self->label_details_size_download_title);
+		gtk_widget_show (self->label_details_size_download_value);
+	} else {
+		gtk_widget_hide (self->label_details_size_download_title);
+		gtk_widget_hide (self->label_details_size_download_value);
+	}
+}
+
 static void
 gs_details_page_refresh_all (GsDetailsPage *self)
 {
@@ -884,42 +910,15 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 		gtk_label_set_label (GTK_LABEL (self->label_details_version_value), C_("version", "Unknown"));
 	}
 
-	/* set the installed size */
-	if (gs_app_get_size_installed (self->app) != GS_APP_SIZE_UNKNOWABLE &&
-	    gs_app_get_size_installed (self->app) != 0) {
-		g_autofree gchar *size = NULL;
-		size = g_format_size (gs_app_get_size_installed (self->app));
-		gtk_label_set_label (GTK_LABEL (self->label_details_size_installed_value), size);
-		gtk_widget_show (self->label_details_size_installed_title);
-		gtk_widget_show (self->label_details_size_installed_value);
-	} else {
-		gtk_widget_hide (self->label_details_size_installed_title);
-		gtk_widget_hide (self->label_details_size_installed_value);
-	}
-
-	/* set the download size */
-	if (!gs_app_is_installed (self->app) &&
-	    gs_app_get_size_download (self->app) != GS_APP_SIZE_UNKNOWABLE) {
-		g_autofree gchar *size = NULL;
-		size = g_format_size (gs_app_get_size_download (self->app));
-		gtk_label_set_label (GTK_LABEL (self->label_details_size_download_value), size);
-		gtk_widget_show (self->label_details_size_download_title);
-		gtk_widget_show (self->label_details_size_download_value);
-	} else {
-		gtk_widget_hide (self->label_details_size_download_title);
-		gtk_widget_hide (self->label_details_size_download_value);
-	}
+	/* refresh size information */
+	gs_details_page_refresh_size (self);
 
 	/* set the updated date */
 	updated = gs_app_get_install_date (self->app);
-	if (updated == GS_APP_INSTALL_DATE_UNSET) {
-		gtk_widget_set_visible (self->label_details_updated_title, FALSE);
-		gtk_widget_set_visible (self->label_details_updated_value, FALSE);
-	} else if (updated == GS_APP_INSTALL_DATE_UNKNOWN) {
+	if (updated == GS_APP_INSTALL_DATE_UNKNOWN ||
+	    updated == GS_APP_INSTALL_DATE_UNSET) {
 		/* TRANSLATORS: this is where the updated date is not known */
 		gtk_label_set_label (GTK_LABEL (self->label_details_updated_value), C_("updated", "Never"));
-		gtk_widget_set_visible (self->label_details_updated_title, TRUE);
-		gtk_widget_set_visible (self->label_details_updated_value, TRUE);
 	} else {
 		g_autoptr(GDateTime) dt = NULL;
 		g_autofree gchar *updated_str = NULL;
@@ -938,8 +937,6 @@ gs_details_page_refresh_all (GsDetailsPage *self)
 			gtk_label_set_markup (GTK_LABEL (self->label_details_updated_value), url->str);
 			g_string_free (url, TRUE);
 		}
-		gtk_widget_set_visible (self->label_details_updated_title, TRUE);
-		gtk_widget_set_visible (self->label_details_updated_value, TRUE);
 	}
 
 	/* set the category */
@@ -1351,15 +1348,13 @@ gs_details_page_refresh_reviews (GsDetailsPage *self)
 		}
 		gs_review_row_set_actions (GS_REVIEW_ROW (row), actions);
 		gtk_container_add (GTK_CONTAINER (self->list_box_reviews), row);
-		gtk_widget_set_visible (row, self->show_all_reviews ||
-					     i < SHOW_NR_REVIEWS_INITIAL);
+		gtk_widget_set_visible (row, i < SHOW_NR_REVIEWS_INITIAL);
 		gs_review_row_set_network_available (GS_REVIEW_ROW (row),
 						     gs_plugin_loader_get_network_available (self->plugin_loader));
 	}
 
 	/* only show the button if there are more to show */
 	gtk_widget_set_visible (self->button_more_reviews,
-				!self->show_all_reviews &&
 				reviews->len > SHOW_NR_REVIEWS_INITIAL);
 
 	/* show the button only if the user never reviewed */
@@ -1389,6 +1384,7 @@ gs_details_page_app_refine2_cb (GObject *source,
 			   error->message);
 		return;
 	}
+	gs_details_page_refresh_size (self);
 	gs_details_page_refresh_reviews (self);
 
 	/* seems a good place */
@@ -1399,12 +1395,16 @@ static void
 gs_details_page_app_refine2 (GsDetailsPage *self)
 {
 	g_autoptr(GsPluginJob) plugin_job = NULL;
+
+	/* if these tasks fail (e.g. because we have no networking) then it's
+	 * of no huge importance if we don't get the required data */
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REFINE,
 					 "app", self->app,
-					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEW_RATINGS |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEWS,
+							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_REVIEWS |
+							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_SIZE,
 					 NULL);
 	gs_plugin_loader_job_process_async (self->plugin_loader, plugin_job,
 					    self->cancellable,
@@ -1526,9 +1526,6 @@ set_app (GsDetailsPage *self, GsApp *app)
 {
 	g_autofree gchar *tmp = NULL;
 
-	/* do not show all the reviews by default */
-	self->show_all_reviews = FALSE;
-
 	/* disconnect the old handlers */
 	if (self->app != NULL) {
 		g_signal_handlers_disconnect_by_func (self->app, gs_details_page_notify_state_changed_cb, self);
@@ -1676,7 +1673,8 @@ gs_details_page_set_url (GsDetailsPage *self, const gchar *url)
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_RELATED |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_RUNTIME |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_SCREENSHOTS,
+							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_SCREENSHOTS |
+							 GS_PLUGIN_REFINE_FLAGS_ALLOW_PACKAGES,
 					 NULL);
 	gs_plugin_loader_job_process_async (self->plugin_loader, plugin_job,
 					    self->cancellable,
@@ -1694,7 +1692,6 @@ gs_details_page_load (GsDetailsPage *self)
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_LICENSE |
-							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_SIZE |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_HISTORY |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION |
@@ -1971,7 +1968,6 @@ gs_details_page_app_removed (GsPage *page, GsApp *app)
 static void
 gs_details_page_more_reviews_button_cb (GtkWidget *widget, GsDetailsPage *self)
 {
-	self->show_all_reviews = TRUE;
 	gtk_container_foreach (GTK_CONTAINER (self->list_box_reviews),
 			       (GtkCallback) gtk_widget_show, NULL);
 	gtk_widget_set_visible (self->button_more_reviews, FALSE);
@@ -2170,7 +2166,18 @@ gs_details_page_license_nonfree_cb (GtkWidget *widget, GsDetailsPage *self)
 {
 	g_autofree gchar *str = NULL;
 	g_autofree gchar *uri = NULL;
-	uri = g_settings_get_string (self->settings, "nonfree-software-uri");
+	g_auto(GStrv) tokens = NULL;
+
+	/* license specified as a link */
+	tokens = as_utils_spdx_license_tokenize (gs_app_get_license (self->app));
+	for (guint i = 0; tokens[i] != NULL; i++) {
+		if (g_str_has_prefix (tokens[i], "@LicenseRef-proprietary=")) {
+			uri = g_strdup (tokens[i] + 24);
+			break;
+		}
+	}
+	if (uri == NULL)
+		uri = g_settings_get_string (self->settings, "nonfree-software-uri");
 	str = g_strdup_printf ("<a href=\"%s\">%s</a>",
 			       uri,
 			       _("More information"));
@@ -2353,7 +2360,6 @@ gs_details_page_class_init (GsDetailsPageClass *klass)
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_size_download_value);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_size_installed_title);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_size_installed_value);
-	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_updated_title);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_updated_value);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_details_version_value);
 	gtk_widget_class_bind_template_child (widget_class, GsDetailsPage, label_failed);
