@@ -58,7 +58,6 @@ typedef struct
 	GtkWidget		*bin_featured;
 	GtkWidget		*box_overview;
 	GtkWidget		*box_popular;
-	GtkWidget		*box_popular_rotating;
 	GtkWidget		*box_recent;
 	GtkWidget		*featured_heading;
 	GtkWidget		*category_heading;
@@ -168,21 +167,13 @@ gs_overview_page_get_popular_cb (GObject *source_object,
 
 	/* get popular apps */
 	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
+	gtk_widget_set_visible (priv->box_popular, list != NULL);
+	gtk_widget_set_visible (priv->popular_heading, list != NULL);
 	if (list == NULL) {
 		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
 			g_warning ("failed to get popular apps: %s", error->message);
 		goto out;
 	}
-
-	/* not enough to show */
-	if (gs_app_list_length (list) < N_TILES) {
-		g_warning ("Only %u apps for popular list, hiding",
-		           gs_app_list_length (list));
-		gtk_widget_set_visible (priv->box_popular, FALSE);
-		gtk_widget_set_visible (priv->popular_heading, FALSE);
-		goto out;
-	}
-
 	/* Don't show apps from the category that's currently featured as the category of the day */
 	gs_app_list_filter (list, filter_category, priv->category_of_day);
 	gs_app_list_randomize (list);
@@ -196,8 +187,6 @@ gs_overview_page_get_popular_cb (GObject *source_object,
 			  G_CALLBACK (app_tile_clicked), self);
 		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
-	gtk_widget_set_visible (priv->box_popular, TRUE);
-	gtk_widget_set_visible (priv->popular_heading, TRUE);
 
 	priv->empty = FALSE;
 
@@ -337,14 +326,14 @@ gs_overview_page_get_category_apps_cb (GObject *source_object,
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (gs_overview_page_category_more_cb), self);
 	gtk_container_add (GTK_CONTAINER (headerbox), button);
-	gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), headerbox);
+	gtk_container_add (GTK_CONTAINER (priv->box_overview), headerbox);
 
 	/* add hiding box */
 	box = gs_hiding_box_new ();
 	gs_hiding_box_set_spacing (GS_HIDING_BOX (box), 14);
 	gtk_widget_set_visible (box, TRUE);
 	gtk_widget_set_valign (box, GTK_ALIGN_START);
-	gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), box);
+	gtk_container_add (GTK_CONTAINER (priv->box_overview), box);
 
 	/* add all the apps */
 	for (i = 0; i < gs_app_list_length (list) && i < N_TILES; i++) {
@@ -379,6 +368,12 @@ gs_overview_page_get_featured_cb (GObject *source_object,
 	if (g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
 		goto out;
 
+	if (g_getenv ("GNOME_SOFTWARE_FEATURED") == NULL) {
+		/* Don't show apps from the category that's currently featured as the category of the day */
+		gs_app_list_filter (list, filter_category, priv->category_of_day);
+		gs_app_list_randomize (list);
+	}
+
 	gtk_widget_hide (priv->featured_heading);
 	gs_container_remove_all (GTK_CONTAINER (priv->bin_featured));
 	if (list == NULL) {
@@ -392,12 +387,6 @@ gs_overview_page_get_featured_cb (GObject *source_object,
 		goto out;
 	}
 
-	if (g_getenv ("GNOME_SOFTWARE_FEATURED") == NULL) {
-		/* Don't show apps from the category that's currently featured as the category of the day */
-		gs_app_list_filter (list, filter_category, priv->category_of_day);
-		gs_app_list_randomize (list);
-	}
-
 	/* at the moment, we only care about the first app */
 	app = gs_app_list_index (list, 0);
 	tile = gs_feature_tile_new (app);
@@ -560,7 +549,7 @@ gs_overview_page_load (GsOverviewPage *self)
 		priv->loading_featured = TRUE;
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_FEATURED,
 						 "max-results", 5,
-						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 						 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
 						 NULL);
 		gs_plugin_loader_job_process_async (priv->plugin_loader,
@@ -577,7 +566,7 @@ gs_overview_page_load (GsOverviewPage *self)
 		priv->loading_popular = TRUE;
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_POPULAR,
 						 "max-results", 20,
-						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 						 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 								 GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
 						 NULL);
@@ -596,7 +585,7 @@ gs_overview_page_load (GsOverviewPage *self)
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_RECENT,
 						 "age", (guint64) (60 * 60 * 24 * 60),
 						 "max-results", 20,
-						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 						 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 								 GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
 						 NULL);
@@ -613,9 +602,6 @@ gs_overview_page_load (GsOverviewPage *self)
 		g_autoptr(GPtrArray) cats_random = NULL;
 		cats_random = gs_overview_page_get_random_categories ();
 
-		/* remove existing widgets, if any */
-		gs_container_remove_all (GTK_CONTAINER (priv->box_popular_rotating));
-
 		/* load all the categories */
 		for (i = 0; i < cats_random->len && i < MAX_CATS; i++) {
 			LoadData *load_data;
@@ -640,7 +626,7 @@ gs_overview_page_load (GsOverviewPage *self)
 			plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_CATEGORY_APPS,
 							 "max-results", 20,
 							 "category", featured_category,
-							 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+							 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 							 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_RATING |
 									 GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON,
 							 NULL);
@@ -658,7 +644,7 @@ gs_overview_page_load (GsOverviewPage *self)
 		g_autoptr(GsPluginJob) plugin_job = NULL;
 		priv->loading_categories = TRUE;
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_CATEGORIES,
-						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 						 NULL);
 		gs_plugin_loader_job_get_categories_async (priv->plugin_loader, plugin_job,
 							  priv->cancellable,
@@ -805,7 +791,7 @@ gs_overview_page_rescan_proprietary_sources (GsOverviewPage *self)
 	g_autoptr(GsPluginJob) plugin_job = NULL;
 
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_SOURCES,
-					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION,
 					 NULL);
 	gs_plugin_loader_job_process_async (priv->plugin_loader,
@@ -866,13 +852,7 @@ gs_overview_page_refresh_proprietary (GsOverviewPage *self)
 						uri, _("Find out more…"));
 		}
 		gtk_label_set_markup (GTK_LABEL (priv->label_proprietary), str->str);
-#if 0
 		gtk_widget_set_visible (priv->infobar_proprietary, TRUE);
-#else
-		/* temporarily disabled until we've updated the text and synced
-		 * up with what gnome-initial-setup is doing */
-		gtk_widget_set_visible (priv->infobar_proprietary, FALSE);
-#endif
 	} else {
 		gtk_widget_set_visible (priv->infobar_proprietary, FALSE);
 	}
@@ -922,10 +902,9 @@ gs_overview_page_setup (GsPage *page,
 		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
 
-	for (i = 0; i < N_TILES; i++) {
-		tile = gs_popular_tile_new (NULL);
-		gtk_container_add (GTK_CONTAINER (priv->box_recent), tile);
-	}
+	/* hide unless there are enough apps */
+	gtk_widget_set_visible (priv->box_recent, FALSE);
+	gtk_widget_set_visible (priv->recent_heading, FALSE);
 
 	/* handle category expander */
 	g_signal_connect (priv->categories_expander_button_down, "clicked",
@@ -1018,7 +997,6 @@ gs_overview_page_class_init (GsOverviewPageClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, bin_featured);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular_rotating);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_recent);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, category_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, featured_heading);
