@@ -41,7 +41,6 @@ struct _GsSearchPage
 	GCancellable		*search_cancellable;
 	GtkSizeGroup		*sizegroup_image;
 	GtkSizeGroup		*sizegroup_name;
-	GtkSizeGroup		*sizegroup_desc;
 	GtkSizeGroup		*sizegroup_button;
 	GsShell			*shell;
 	gchar			*appid_to_show;
@@ -141,7 +140,6 @@ gs_search_page_get_search_cb (GObject *source_object,
 		gs_app_row_set_size_groups (GS_APP_ROW (app_row),
 					    self->sizegroup_image,
 					    self->sizegroup_name,
-					    self->sizegroup_desc,
 					    self->sizegroup_button);
 		gtk_widget_show (app_row);
 	}
@@ -235,6 +233,9 @@ gs_search_page_get_app_sort_key (GsApp *app)
 	/* sort by kudos */
 	g_string_append_printf (key, "%03u:", gs_app_get_kudos_percentage (app));
 
+	/* tie-break with id */
+	g_string_append (key, gs_app_get_unique_id (app));
+
 	return g_string_free (key, FALSE);
 }
 
@@ -267,7 +268,7 @@ gs_search_page_load (GsSearchPage *self)
 					 "search", self->value,
 					 "max-results", self->max_results,
 					 "timeout", 10,
-					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 					 "refine-flags", GS_PLUGIN_REFINE_FLAGS_REQUIRE_ICON |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION |
 							 GS_PLUGIN_REFINE_FLAGS_REQUIRE_PROVENANCE |
@@ -453,7 +454,6 @@ gs_search_page_dispose (GObject *object)
 
 	g_clear_object (&self->sizegroup_image);
 	g_clear_object (&self->sizegroup_name);
-	g_clear_object (&self->sizegroup_desc);
 	g_clear_object (&self->sizegroup_button);
 
 	g_clear_object (&self->builder);
@@ -505,7 +505,6 @@ gs_search_page_init (GsSearchPage *self)
 
 	self->sizegroup_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_name = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	self->sizegroup_desc = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_button = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
 	self->max_results = GS_SEARCH_PAGE_MAX_RESULTS;
