@@ -502,7 +502,8 @@ gs_shell_go_back (GsShell *shell)
 
 	switch (entry->mode) {
 	case GS_SHELL_MODE_UNKNOWN:
-		/* only happens when the user does --search foobar */
+	case GS_SHELL_MODE_LOADING:
+		/* happens when using --search, --details, --install, etc. options */
 		g_debug ("popping back entry for %s", page_name[entry->mode]);
 		gs_shell_change_mode (shell, GS_SHELL_MODE_OVERVIEW, NULL, FALSE);
 		break;
@@ -660,7 +661,7 @@ window_key_press_event (GtkWidget *win, GdkEventKey *event, GsShell *shell)
 	    	return GDK_EVENT_PROPAGATE;
 
 	state = event->state;
-	keymap = gdk_keymap_get_for_display (gtk_widget_get_display (win));
+	keymap = gdk_keymap_get_default ();
 	gdk_keymap_add_virtual_modifiers (keymap, &state);
 	state = state & gtk_accelerator_get_default_mod_mask ();
 	is_rtl = gtk_widget_get_direction (button) == GTK_TEXT_DIR_RTL;
@@ -1665,9 +1666,9 @@ gs_shell_events_notify_cb (GsPluginLoader *plugin_loader,
 static void
 gs_shell_plugin_event_dismissed_cb (GtkButton *button, GsShell *shell)
 {
+	GPtrArray *events;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	guint i;
-	g_autoptr(GPtrArray) events = NULL;
 
 	/* mark any events currently showing as invalid */
 	events = gs_plugin_loader_get_events (priv->plugin_loader);
@@ -1989,7 +1990,6 @@ gs_shell_show_uri (GsShell *shell, const gchar *url)
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	g_autoptr(GError) error = NULL;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
 	if (!gtk_show_uri_on_window (priv->main_window,
 	                             url,
 	                             GDK_CURRENT_TIME,
@@ -1997,15 +1997,6 @@ gs_shell_show_uri (GsShell *shell, const gchar *url)
 		g_warning ("failed to show URI %s: %s",
 		           url, error->message);
 	}
-#else
-	if (!gtk_show_uri (NULL,
-	                   url,
-	                   GDK_CURRENT_TIME,
-	                   &error)) {
-		g_warning ("failed to show URI %s: %s",
-		           url, error->message);
-	}
-#endif
 }
 
 static void
