@@ -32,7 +32,6 @@ typedef struct
 {
 	GtkSizeGroup		*sizegroup_image;
 	GtkSizeGroup		*sizegroup_name;
-	GtkSizeGroup		*sizegroup_desc;
 } GsUpdateListPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsUpdateList, gs_update_list, GTK_TYPE_LIST_BOX)
@@ -59,11 +58,10 @@ gs_update_list_add_app (GsUpdateList *update_list, GsApp *app)
 	gs_app_row_set_size_groups (GS_APP_ROW (app_row),
 				    priv->sizegroup_image,
 				    priv->sizegroup_name,
-				    priv->sizegroup_desc,
 				    NULL);
-	g_signal_connect_object (app, "notify::state",
-	                         G_CALLBACK (gs_update_list_app_state_notify_cb),
-	                         app_row, 0);
+	g_signal_connect (app, "notify::state",
+			  G_CALLBACK (gs_update_list_app_state_notify_cb),
+			  app_row);
 	gtk_widget_show (app_row);
 }
 
@@ -95,7 +93,6 @@ gs_update_list_dispose (GObject *object)
 
 	g_clear_object (&priv->sizegroup_image);
 	g_clear_object (&priv->sizegroup_name);
-	g_clear_object (&priv->sizegroup_desc);
 
 	G_OBJECT_CLASS (gs_update_list_parent_class)->dispose (object);
 }
@@ -106,7 +103,6 @@ gs_update_list_init (GsUpdateList *update_list)
 	GsUpdateListPrivate *priv = gs_update_list_get_instance_private (update_list);
 	priv->sizegroup_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	priv->sizegroup_name = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	priv->sizegroup_desc = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
 	gtk_list_box_set_header_func (GTK_LIST_BOX (update_list),
 				      list_header_func,
