@@ -108,7 +108,6 @@ struct _GsUpdatesPage
 
 	GtkSizeGroup		*sizegroup_image;
 	GtkSizeGroup		*sizegroup_name;
-	GtkSizeGroup		*sizegroup_desc;
 	GtkSizeGroup		*sizegroup_button;
 	GtkSizeGroup		*sizegroup_header;
 	GtkListBox		*listboxes[GS_UPDATE_PAGE_SECTION_LAST];
@@ -200,13 +199,35 @@ _get_all_apps (GsUpdatesPage *self)
 {
 	GsAppList *apps = gs_app_list_new ();
 	for (guint i = 0; i < GS_UPDATE_PAGE_SECTION_LAST; i++) {
-		g_autoptr(GsAppList) apps_tmp = NULL;
-		apps_tmp = _get_apps_for_section (self, i);
-		gs_app_list_add_list (apps, apps_tmp);
+		g_autoptr(GList) children = NULL;
+
+		if (self->listboxes[i] == NULL)
+			continue;
+
+		children = gtk_container_get_children (GTK_CONTAINER (self->listboxes[i]));
+		for (GList *l = children; l != NULL; l = l->next) {
+			GsAppRow *app_row = GS_APP_ROW (l->data);
+			gs_app_list_add (apps, gs_app_row_get_app (app_row));
+		}
 	}
 	return apps;
 }
 
+static guint
+_get_num_updates (GsUpdatesPage *self)
+{
+	guint count = 0;
+	g_autoptr(GsAppList) apps = _get_all_apps (self);
+
+	for (guint i = 0; i < gs_app_list_length (apps); ++i) {
+		GsApp *app = gs_app_list_index (apps, i);
+		if (gs_app_is_updatable (app) ||
+		    gs_app_get_state (app) == AS_APP_STATE_INSTALLING)
+			++count;
+	}
+	return count;
+}
+
 static gboolean
 _get_has_headers (GsUpdatesPage *self)
 {
@@ -328,9 +349,11 @@ gs_updates_page_get_state_string (GsPluginStatus status)
 static void
 gs_updates_page_update_ui_state (GsUpdatesPage *self)
 {
+	GtkWidget *widget = NULL;
 	gboolean allow_mobile_refresh = TRUE;
 	g_autofree gchar *checked_str = NULL;
 	g_autofree gchar *spinner_str = NULL;
+	guint num_updates = 0;
 
 	if (gs_shell_get_mode (self->shell) != GS_SHELL_MODE_UPDATES)
 		return;
@@ -480,6 +503,26 @@ gs_updates_page_update_ui_state (GsUpdatesPage *self)
 		}
 		gtk_widget_set_visible (self->label_updates_last_checked, checked_str != NULL);
 	}
+
+	/* set the right updates count */
+	num_updates = _get_num_updates (self);
+	widget = GTK_WIDGET (gtk_builder_get_object (self->builder, "button_updates_counter"));
+	if (num_updates > 0 &&
+	    gs_plugin_loader_get_allow_updates (self->plugin_loader)) {
+		g_autofree gchar *text = NULL;
+		text = g_strdup_printf ("%u", num_updates);
+		gtk_label_set_label (GTK_LABEL (widget), text);
+		gtk_widget_show (widget);
+	} else {
+		gtk_widget_hide (widget);
+	}
+
+	/* update the tab style */
+	if (num_updates > 0 &&
+	    gs_shell_get_mode (self->shell) != GS_SHELL_MODE_UPDATES)
+		gtk_style_context_add_class (gtk_widget_get_style_context (widget), "needs-attention");
+	else
+		gtk_style_context_remove_class (gtk_widget_get_style_context (widget), "needs-attention");
 }
 
 static void
@@ -933,11 +976,10 @@ _add_app_row (GsUpdatesPage *self, GsApp *app)
 	gs_app_row_set_size_groups (GS_APP_ROW (app_row),
 				    self->sizegroup_image,
 				    self->sizegroup_name,
-				    self->sizegroup_desc,
 				    self->sizegroup_button);
-	g_signal_connect_object (app, "notify::state",
-	                         G_CALLBACK (_app_state_notify_cb),
-	                         app_row, 0);
+	g_signal_connect (app, "notify::state",
+			  G_CALLBACK (_app_state_notify_cb),
+			  app_row);
 }
 
 static void
@@ -992,26 +1034,6 @@ gs_updates_page_get_updates_cb (GsPluginLoader *plugin_loader,
 				      _("U_pdate All"));
 	}
 
-	/* update the counter */
-	widget = GTK_WIDGET (gtk_builder_get_object (self->builder,
-						     "button_updates_counter"));
-	if (gs_app_list_length (list) > 0 &&
-	    gs_plugin_loader_get_allow_updates (self->plugin_loader)) {
-		g_autofree gchar *text = NULL;
-		text = g_strdup_printf ("%u", gs_app_list_length (list));
-		gtk_label_set_label (GTK_LABEL (widget), text);
-		gtk_widget_show (widget);
-	} else {
-		gtk_widget_hide (widget);
-	}
-
-	/* update the tab style */
-	if (gs_app_list_length (list) > 0 &&
-	    gs_shell_get_mode (self->shell) != GS_SHELL_MODE_UPDATES)
-		gtk_style_context_add_class (gtk_widget_get_style_context (widget), "needs-attention");
-	else
-		gtk_style_context_remove_class (gtk_widget_get_style_context (widget), "needs-attention");
-
 	/* no results */
 	if (gs_app_list_length (list) == 0) {
 		g_debug ("updates-shell: no updates to show");
@@ -1079,11 +1101,6 @@ gs_updates_page_get_system_finished_cb (GObject *source_object,
 
 	/* show or hide the end of life notification */
 	app = gs_plugin_loader_get_system_app (plugin_loader);
-	if (app == NULL) {
-		g_warning ("failed to get system app");
-		gtk_widget_set_visible (self->box_end_of_life, FALSE);
-		return;
-	}
 	if (gs_app_get_state (app) != AS_APP_STATE_UNAVAILABLE) {
 		gtk_widget_set_visible (self->box_end_of_life, FALSE);
 		return;
@@ -1137,7 +1154,7 @@ gs_updates_page_load (GsUpdatesPage *self)
 	self->action_cnt++;
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_UPDATES,
 					 "refine-flags", refine_flags,
-					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 					 NULL);
 	gs_plugin_loader_job_process_async (self->plugin_loader, plugin_job,
 					    self->cancellable,
@@ -1162,7 +1179,7 @@ gs_updates_page_load (GsUpdatesPage *self)
 		g_object_unref (plugin_job);
 		plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_GET_DISTRO_UPDATES,
 						 "refine-flags", refine_flags,
-						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
+						 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_NONE,
 						 NULL);
 		gs_plugin_loader_job_process_async (self->plugin_loader,
 						    plugin_job,
@@ -1831,7 +1848,6 @@ gs_updates_page_setup (GsPage *page,
 	/* visually aligned */
 	self->sizegroup_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_name = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	self->sizegroup_desc = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_button = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_header = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 
@@ -1870,7 +1886,6 @@ gs_updates_page_dispose (GObject *object)
 
 	g_clear_object (&self->sizegroup_image);
 	g_clear_object (&self->sizegroup_name);
-	g_clear_object (&self->sizegroup_desc);
 	g_clear_object (&self->sizegroup_button);
 	g_clear_object (&self->sizegroup_header);
 
@@ -1918,7 +1933,6 @@ gs_updates_page_init (GsUpdatesPage *self)
 
 	self->sizegroup_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_name = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	self->sizegroup_desc = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_button = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	self->sizegroup_header = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 
